pywr.parameters.WeeklyProfileParameter — Pywr 0.5dev documentation

# pywr.parameters.WeeklyProfileParameter

class `pywr.parameters.` `WeeklyProfileParameter`

  Weekly profile (52-week year)

  The last week of the year will have more than 7 days, as 365 / 7 is not whole.

  `__init__`($self, /, *args, **kwargs)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `after` |
  `before` |
  `finish` |
  `get_all_values` |
  `get_double_lower_bounds` |
  `get_double_upper_bounds` |
  `get_double_variables` |
  `get_integer_lower_bounds` |
  `get_integer_upper_bounds` |
  `get_integer_variables` |
  `get_value` |
  `load` |
  `lower_bounds` |
  `register` |
  `reset` |
  `set_double_variables` |
  `set_integer_variables` |
  `setup` |
  `unregister` |
  `update` |
  `upper_bounds` |
  `value` |

  Attributes

  `children` |
  `comment` |
  `double_size` |
  `integer_size` |
  `is_variable` |
  `model` |
  `name` |
  `parents` |
  `size` |